@@ -127,9 +127,12 @@ class Loader:
         * List[SomeType]
         * Dict[TypeA, TypeB]
         * Tuple[TypeA, TypeB, TypeC]
+        * Tuple[SomeType, ...]
         * Set[SomeType]
         * Union[TypeA, TypeB]
         * ForwardRef
+        * Literal
+        * Dataclass
 
     Using unions is complicated. If the types in the union are too
     similar to each other, it is easy to obtain an unexpected type.
@@ -173,8 +176,9 @@ class Loader:
             (is_namedtuple, _namedtupleload),
             (is_dataclass, _namedtupleload),
             (is_forwardref, _forwardrefload),
+            (is_literal, _literalload),
             (lambda type_: type_ in {datetime.date, datetime.time, datetime.datetime}, _datetimeload),
-        ]  # type: List[Tuple[Callable[[Type[T]], bool], Callable[['Loader', Any, Type[T]], T]]]
+        ]
 
         for k, v in kwargs.items():
             setattr(self, k, v)
@@ -227,7 +231,7 @@ class Loader:
                 value = {k: v for k,v in value._get_kwargs()}
 
         try:
-            return func(self, value, type_)
+            return cast(T, func(self, value, type_))
         except Exception as e:
             assert isinstance(e, TypedloadException)
             e.trace.insert(0, TraceItem(value, type_, annotation))
@@ -254,6 +258,16 @@ def _forwardrefload(l: Loader, value: Any, type_: type) -> Any:
     return l.load(value, t, annotation=Annotation(AnnotationType.FORWARDREF, tname))
 
 
+def _literalload(l: Loader, value: Any, type_: type) -> Any:
+    """
+    Checks if the value is within the allowed literals and
+    returns it.
+    """
+    if value in literalvalues(type_):
+        return value
+    raise TypedloadValueError('Not one of the allowed values in %s' % type_, value=value, type_=type_)
+
+
 def _basicload(l: Loader, value: Any, type_: type) -> Any:
     """
     This converts a value into a basic type.
